@@ -1,14 +1,19 @@
 from osys import *
 from tk import *
 
+
 def createPyGui(name):
     python(name)
-def shutdown():
-    os.Shutdown()
+
+
 def create(name):
     os.append(name)
-def echo(name,value):
-    os.echo(name,value)
-def createPy(name,value):
+
+
+def echo(name, value):
+    os.echo(name, value)
+
+
+def createPy(name, value):
     create(name)
-    echo(name,value)
\ No newline at end of file
+    echo(name, value)
